==> quix-1.00.tar.gz: quix-1.00/quix.h <==
/*****************************************
 PROJEKT: Quix
 ZWECK: Leitet Absender, Subject und Teil
		einer ankommenden Mail an Quix weiter

 AUTOR: Marek Tomczyk (E-mail: Marek.Tomczyk@stud.uni-karlsruhe.de)
 DATUM: 11.08.1997

 AENDERUNGSHISTORIE

 AENDERUNG:
 AUTOR:
 DATUM:

 VERSION: 1.0

 Copyright (C) 1997 Marek Tomczyk

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

******************************************/

/* Hier sind Angaben, die speziell an Ihr System
   angepasst werden muessen */

/* Absoluter Pfad des Kommandos 'frm', welches aus der Mailbox
   die Indexnummer einer Mail sowie Absender und Subject
   liefert */
#define MAILCHECK "/usr/segment/bin/frm -n /home/ws/un55/mailbox"


/* Absoluter Pfad des Kommandos 'readmsg', welches anhand
   der Indexnummer den Mailinhalt liefert */
#define READMSG "/usr/segment/bin/readmsg -n -f /home/ws/un55/mailbox"


/* Absoluter Pfad des Fules, in dem 'quix' sich merkt,
   welche Mails schon verschickt wurden (Name beliebig) */
#define QUIXHISTORY "/home/ws/un55/.quixhistory"

/* absoluter Pfad eines Mailkommandos, welches
   Mails von der Shell aus verschicken kann. Es muss
   in der Form funktionnieren:
   echo "muell" | kommando -s "subject" ampfaenger@sonst.wo
   
   (z.B. 'elm' kann so etwas) */
#define MAILCMD "/usr/segment/bin/elm"

/* das wichtigste: die Mailadresse Ihres Quix-Empfaengers */
#define QUIXADDR "1234567@quix-it.de"


/* Ab hier sollten Sie nichts mehr aendern muessen */

#define OK 0
#define FALSE 0
#define TRUE 1
#define BUFLEN 1000

char *kill_blankF(char *instr);

typedef struct {
    char *subject; /* Autor der Mail und Subject */
    int  index;       /* Indexnummer der Mail */
    char *mailcontent; /* Mailinhalt */
  } mailT;

==> quix-1.02.tar.gz: quix-1.02/quix.h <==
/*****************************************
 PROJEKT: Quix
 ZWECK: Leitet Absender, Subject und Teil
		einer ankommenden Mail an Quix weiter

 AUTOR: Marek Tomczyk (E-mail: Marek.Tomczyk@stud.uni-karlsruhe.de)
 DATUM: 11.08.1997

 AENDERUNGSHISTORIE

 AENDERUNG: Ueberfluessige Leerzeichen im Mailinhalt werden entfernt
 AUTOR: Marek Tomczyk
 DATUM: 05.11.1997

 AENDERUNG: - Zeilenumbruch verwirrte Quix-Gateway --> durch Leerzeichen ersetzt
            - Quix-Gateway kann jetzt Messages mit bis zu 117 Zeichen 
              Laenge verkraften --> Programm angepasst
 AUTOR: Marek Tomczyk
 DATUM: 02.12.1997

 Copyright (C) 1997 Marek Tomczyk

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

******************************************/

/* Hier sind Angaben, die speziell an Ihr System
   angepasst werden muessen */

/* Absoluter Pfad des Kommandos 'frm', welches aus der Mailbox
   die Indexnummer einer Mail sowie Absender und Subject
   liefert */
#define MAILCHECK "/usr/segment/bin/frm -n /home/ws/un55/mailbox"


/* Absoluter Pfad des Kommandos 'readmsg', welches anhand
   der Indexnummer den Mailinhalt liefert */
#define READMSG "/usr/segment/bin/readmsg -n -f /home/ws/un55/mailbox"


/* Absoluter Pfad des Fules, in dem 'quix' sich merkt,
   welche Mails schon verschickt wurden (Name beliebig) */
#define QUIXHISTORY "/home/ws/un55/.quixhistory"

/* absoluter Pfad eines Mailkommandos, welches
   Mails von der Shell aus verschicken kann. Es muss
   in der Form funktionnieren:
   echo "muell" | kommando -s "subject" ampfaenger@sonst.wo
   
   (z.B. 'elm' kann so etwas) */
#define MAILCMD "/usr/segment/bin/elm"

/* das wichtigste: die Mailadresse Ihres Quix-Empfaengers */
#define QUIXADDR "1234567@quix-it.de"


/* Ab hier sollten Sie nichts mehr aendern muessen */

#define OK 0
#define FALSE 0
#define TRUE 1
#define BUFLEN 1000

char *kill_blankF(char *instr);

typedef struct {
    char *subject; /* Autor der Mail und Subject */
    int  index;       /* Indexnummer der Mail */
    char *mailcontent; /* Mailinhalt */
  } mailT;
